# py-irclib

[![Build Status](https://travis-ci.org/TotallyNotRobots/py-irclib.svg?branch=master)](https://travis-ci.org/TotallyNotRobots/py-irclib)
[![PyPI Release](https://img.shields.io/pypi/v/py-irclib.svg)](https://pypi.org/project/py-irclib/)
[![Python Versions](https://img.shields.io/pypi/pyversions/py-irclib.svg)](https://pypi.org/project/py-irclib/)

A Python library for working with the IRC protocol
